
# %%
'''
Gráfico de linha simples
'''
from experimentalTreatingIsiPol.main import plot_helper
import numpy as np
import matplotlib.pyplot as plt


fig, ax = plt.subplots(figsize=(6, 5))
n_samples = 100
ax = plot_helper(ax, x=np.linspace(1,n_samples, n_samples), 
            y=np.random.normal(5,0.01, n_samples), 
            xlabel='Amostra', ylabel='Espessura [mm]', 
            label=r"Espessuras dos CP's, $\mu=5 [mm]$ e $\sigma=0.01 [mm]$")

fig.savefig('grafico_linha_simples.svg')

# %%
'''
Gráfico de linha simples, sem grid
'''
from experimentalTreatingIsiPol.main import plot_helper
import numpy as np
import matplotlib.pyplot as plt


fig, ax = plt.subplots(figsize=(6, 5))
n_samples = 100
ax = plot_helper(ax, x=np.linspace(1,n_samples, n_samples), 
            y=np.random.normal(5,0.01, n_samples), 
            xlabel='Amostra', ylabel='Espessura [mm]', 
            label=r"Espessuras dos CP's, $\mu=5 [mm]$ e $\sigma=0.01 [mm]$")

ax.grid()
fig.savefig('grafico_linha_simples_sem_grid.svg')

# %%
from experimentalTreatingIsiPol.main import scatter_helper
import numpy as np
import matplotlib.pyplot as plt


fig, ax = plt.subplots(figsize=(6, 5))
n_samples = 100
ax = scatter_helper(ax, x=np.linspace(1,n_samples, n_samples), 
            y=np.random.normal(5,0.01, n_samples), 
            xlabel='Amostra', ylabel='Espessura [mm]', 
            label=r"Espessuras dos CP's, $\mu=5 [mm]$ e $\sigma=0.01 [mm]$")

fig.savefig('grafico_dispersao.svg')
# %%
'''
Vários gráficos no mesmo meixo eixo (Método 1)
'''
from experimentalTreatingIsiPol.main import plot_helper, color_rnd
import numpy as np
import matplotlib.pyplot as plt


fig, ax = plt.subplots(figsize=(6, 5))
x = np.linspace(-10,10)
y1 = np.multiply(x,2)
y2 = np.power(x,1/2)
ax = scatter_helper(ax, x=x,
            y=y1, 
            xlabel='x', ylabel='y', 
            label=r"$2x$", color=color_rnd[0])

ax = scatter_helper(ax, x=x,
            y=y2, 
            xlabel='x', ylabel='y', 
            label=r"$x^{\frac{1}{2}}$", color = color_rnd[5], )


# %%
'''
Demonstração da alteração de estilos
'''
import matplotlib.pyplot as plt
from experimentalTreatingIsiPol.main import plot_helper

fig, (ax,ax2) = plt.subplots(1,2,figsize=(10, 3))

x=np.linspace(-10,10)
y1=np.power(x,2)
y2=np.power(x,3)/3

ax = plot_helper(ax,x=x,y=y1, label=r'$y=x^2$', xlabel='x', ylabel='y')
ax.set_title(r"$Math\ mode\ : x^2$",
             math_fontfamily='stixsans', size=14, family='cursive')

ax2 = plot_helper(ax2,x=x,y=y2, label=r'$y=1/3x^3$', xlabel='x', ylabel='y')
ax2.set_title(r"Título em cursivo $\int x^2 dx$",
             math_fontfamily='stixsans', size=14, family='cursive')

fig.savefig('plot_diferentes_fontes.svg')


# %%
import matplotlib.pyplot as plt

fig, ax = plt.subplots(figsize=(6, 5))

# A simple plot for the background.
x = np.linspace(1,10,10)
y = np.random.standard_normal(10)

ax.plot(x,y,color="0.9", label='Alguma legenda com tamanho 7')
ax.set_xlabel('Título do eixo x, com tamanho 8', fontsize = 8)
ax.set_ylabel('Título do eixo x, com tamanho 8', fontsize = 8)
ax.legend(fontsize=7)
ax.tick_params(axis='x', labelsize=5) # fonte dos pontos do eixo x com tamanho 5
plt.show()


# %%
import matplotlib as mtp

mtp.rcParams['legend.fontsize'] = 7 # Fonte global da legenda
mtp.rcParams['xtick.labelsize'] = 5 # Fonte dos pontos do eixo x com tamanho 5
mtp.rcParams['axes.labelsize'] = 8 # Fonte dos eixos x e y

fig, ax = plt.subplots(figsize=(6, 5))

# A simple plot for the background.
x = np.linspace(1,10,10)
y = np.random.standard_normal(10)

ax.plot(x,y,color="0.9", label='Alguma legenda com tamanho 7')
ax.set_xlabel('Título do eixo x, com tamanho 8')
ax.set_ylabel('Título do eixo x, com tamanho 8')
ax.legend()
ax.tick_params(axis='x') # fonte dos pontos do eixo x com tamanho 5
plt.show()

# %%
from experimentalTreatingIsiPol.main import MechanicalTestFittingLinear
import os
archive = os.path.join(os.getcwd(),r'..\DataArquives\Specimen_RawData_1.csv')
classInit =  MechanicalTestFittingLinear(docConfig='68FM100', archive_name=archive)
classInit.MeasureYoungModulus(length = 50,thickess = 1,width = 12)   
# %%



'''
Classe utilizada para testes biaxiais. Isso fere, de certa forma, a filosofia original da ferramenta. Contudo, não vejo outra forma por enquanto de ter dois tipos de arquivo para a mesma máquina
'''

class _alpha():
    def __init__(self) -> None:

        self.colunas  = [
                             r'Time'
                            ,r'Deslocamento [mm]'
                            ,r'Força'
                            ,r'Tensão à tração'
                            ,r'Deformação à tração (Deslocamento)'
                            ,r'Strain Gauge 1/Axial Strain' # Deformação axial
                            ,r'Strain Gauge 1/Transverse Strain' # Deformação transversal
                            ,r'Strain Gauge 1/Shear Strain' # Deformação cisalhante
                            ,r'Strain Gauge 1/Minimum Normal Strain' # Deformação mínima local
                            ,r'Strain Gauge 1/Maximum Normal Strain' # Deformação máxima local
                            ,r'Strain Gauge 1/Poissons Ratio' # Razao de Poisson
                            ,r'Strain Gauge 1/Axial Displacement' # Deslocamento axial
                            ,r'Strain Gauge 1/Transverse Displacement' # Deslocamento transversal
                         ]
        
        self.column_delimitador = ','
        self.decimal = '.'


class _alpha():
    def __init__(self) -> None:

        self.colunas  = [
                             r'Time'
                            ,r'Deslocamento [mm]'
                            ,r'Força'
                            ,r'Tensão à tração'
                            ,r'Deformação à tração (Deslocamento)'
                            ,r'Strain Gauge 1/Axial Strain' # Deformação axial
                            ,r'Strain Gauge 1/Transverse Strain' # Deformação transversal
                            ,r'Strain Gauge 1/Shear Strain' # Deformação cisalhante
                            ,r'Strain Gauge 1/Minimum Normal Strain' # Deformação mínima local
                            ,r'Strain Gauge 1/Maximum Normal Strain' # Deformação máxima local
                            ,r'Strain Gauge 1/Poissons Ratio' # Razao de Poisson
                            ,r'Strain Gauge 1/Axial Displacement' # Deslocamento axial
                            ,r'Strain Gauge 1/Transverse Displacement' # Deslocamento transversal
                         ]

        self.column_delimitador = ','
        self.decimal = '.'
        self.testType = ['tensile']


class _beta():
    def __init__(self) -> None:

        self.colunas  = [
                             r'Tempo'
                            ,r'Deslocamento [mm]'
                            ,r'Força'
                            ,r'Tensão à tração'
                            ,r'Deformação à tração (Deslocamento)'
                            ,r'Extens Bi Axial - Connector 6'
                            ,r'Extens Bi Trans - Conector 5'
                         ]
        self.column_delimitador = ';'
        self.decimal = ','
        self.skip_rows = 18
        self.testType = ['tensile','flexural']



class _gamma():
    def __init__(self) -> None:

        self.colunas  = [
                             r'Tempo'
                            ,r'Deslocamento [mm]'
                            ,r'Força'
                            ,r'Tensão à tração'
                            ,r'Deformação à tração (Deslocamento)'
                            ,r'Deformação digital 1'
                         ]
        self.column_delimitador = ';'
        self.decimal = ','
        self.testType = ['tensile']


class _delta():
    def __init__(self) -> None:

        self.colunas  = [
                             r'Tempo'
                            ,r'Deslocamento [mm]'
                            ,r'Força'
                            ,r'Tensão à tração'
                            ,r'Deformação à tração (Deslocamento)'
                         ]
        self.column_delimitador = ';'
        self.decimal = ','
        self.testType = ['tensile']

class _epsilon():
    def __init__(self) -> None:

        self.colunas  = ['Tempo','Deslocamento','Força','Extensometro']
        self.column_delimitador = ';'
        self.decimal = ','
        self.testType = ['tensile'] # Array com tipos de testes utilizados

class _zeta():
    def __init__(self) -> None:

        self.colunas  = [
                             r'Time measurement'
                            ,r'Extension'
                            ,r'Primary load measurement'
                            ,r'W-E401'
                            ,r'Deformação à flexão (W-E401)'
                            ,r'Deslocamento à flexão'
                            ,r'Tensão à flexão'
        ]
        self.column_delimitador = ';'
        self.decimal = ','
        self.skip_rows = 18
        self.testType = ['flexural'] # Array com tipos de testes utilizados



class _eta():
    def __init__(self) -> None:

        self.colunas  = [
                             r'Time'
                            ,r'Deslocamento [mm]'
                            ,r'Força'
                            ,r'Tensão à tração'
                            ,r'Deformação à tração (Deslocamento)'
                            ,r'Strain Gauge 1/Axial Strain' # Deformação axial
                            ,r'Strain Gauge 1/Transverse Strain' # Deformação transversal
                            ,r'Strain Gauge 1/Shear Strain' # Deformação cisalhante
                            ,r'Strain Gauge 1/Minimum Normal Strain' # Deformação mínima local
                            ,r'Strain Gauge 1/Maximum Normal Strain' # Deformação máxima local
                            ,r'Strain Gauge 1/Poissons Ratio' # Razao de Poisson
                            ,r'Strain Gauge 1/Axial Displacement' # Deslocamento axial
                            ,r'Strain Gauge 1/Transverse Displacement' # Deslocamento transversal
                         ]

        self.column_delimitador = ','
        self.decimal = '.'
        self.testType = ['shear'] # Array com tipos de testes utilizados


class _omicron():
    def __init__(self) -> None:

        self.colunas  = [
                            r'Time',
                            r'Deslocamento',
                            r'Força',
                            r'Tensão ao cisalhamento',
                            r'Deformação ao cisalhamento (Deslocamento)',
                            r'Extensometer 1/Engineering Strain',
                            r'Extensometer 1/True Strain',
                            r'Extensometer 1/Distance Change L(t)-L0',
                            r'Extensometer 1/Distance L(t)',
                            r'Extensometer 2/Engineering Strain',
                            r'Extensometer 2/True Strain',
                            r'Extensometer 2/Distance Change L(t)-L0',
                            r'Extensometer 2/Distance L(t)'
                         ]

        self.column_delimitador = ','
        self.decimal = '.'
        self.skip_rows = 100
        self.testType = ['shear'] # Array com tipos de testes utilizados


class _pi():
    def __init__(self) -> None:

        self.colunas  = [
                             r'Tempo'
                            ,r'Deslocamento'
                            ,r'Força'
                            ,r'Deformação à compressão (Deslocamento)'
                            ,r'Tensão à compressão'
                         ]

        self.column_delimitador = ';'
        self.decimal = ','
        self.skip_rows = 10
        self.testType = ['compression'] # Array com tipos de testes utilizados



class _rho():
    def __init__(self) -> None:

        self.colunas  = [
                             r'Tempo'
                             ,r'Deslocamento'
                            ,r'Força'
                            ,r'Tensão à tração'
                            ,r'Extens Bi Axial - Connector 6'
                            ,r'Extens Bi Trans - Conector 5'
                            ,r'Deformação à tração (Extens Bi Axial - Connector 6)'
                         ]

        self.column_delimitador = ';'
        self.decimal = ','
        self.skip_rows = 30
        self.testType = ['tensile'] # Array com tipos de testes utilizados

class _sigma():
    def __init__(self) -> None:

        self.colunas  = [
                            r"Time",
                            r"Deslocamento",
                            r"Força",
                            r"Tensão à tração",
                            r"Deformação à tração (Deslocamento)",
                            r"Strain Gauge 1/Axial Strain",
                            r"Strain Gauge 1/Transverse Strain",
                            r"Strain Gauge 1/Shear Strain",
                            r"Strain Gauge 1/Minimum Normal Strain",
                            r"Strain Gauge 1/Maximum Normal Strain",
                            r"Strain Gauge 1/Poisson's Ratio",
                            r"Strain Gauge 1/Axial Displacement",
                            r"Strain Gauge 1/Transverse Displacement",
                            r"Extensometer 1/Engineering Strain",
                            r"Extensometer 1/True Strain",
                            r"Extensometer 1/Distance Change L(t)-L0",
                            r"Extensometer 1/Distance L(t)"
                         ]

        self.column_delimitador = ','
        self.decimal = '.'
        self.skip_rows = 100
        self.testType = ['tensile'] # Array com tipos de testes utilizados

docConfigParam = [
                '_alpha'
                ,'_beta'
                ,'_gamma'
                ,'_delta'
                ,'_epsilon'
                ,'_zeta'
                ,'_eta'
                ,'_omicron'
                ,'_pi'
                ,'_rho'
                ,'_sigma'
    ]

def get_docconfig():
    """return all the different doc config"""
    return docConfigParam

mapping_translate = {
    'tensile':'Tração'
    ,'flexural':'Flexão'
    ,'compression':'Compressão'
    ,'shear':'Cisalhamento'
}

def print_docConfig()->str:
    '''
    Função para mostrar cada uma das pré-formatações configuradas para as máquinas.
    '''
    docConfigsClass = [
        _alpha
        ,_beta
        ,_gamma
        ,_delta
        ,_epsilon
        ,_zeta
        ,_eta
        ,_omicron
        ,_pi
        ,_rho
        ,_sigma
    ]

    for each_docConfigClass, each_docConfigName in zip(docConfigsClass, docConfigParam):
        ClassInit = each_docConfigClass()

        string_tests = ""

        for each_test in ClassInit.testType:
            string_tests+=f'''
    - {mapping_translate[each_test]}
'''

        string_coluns = ""
        for each_colum in ClassInit.colunas:
            string_coluns+=f'''
    - {each_colum}
'''
        returned_string = f'''
_________________________________________________________________________________________

================================|  Configuração |========================================
docConfig {each_docConfigName}

Geralmente utilizado para testes de :

{string_tests}
================================|    Colunas    |========================================
{string_coluns}
_________________________________________________________________________________________
'''
        print(returned_string)
        return returned_string



class _beta():
    def __init__(self) -> None:

        self.colunas  = [
                             r'Tempo'
                            ,r'Deslocamento [mm]'
                            ,r'Força'
                            ,r'Tensão à tração'
                            ,r'Deformação à tração (Deslocamento)'
                            ,r'Extens Bi Axial - Connector 6'
                            ,r'Extens Bi Trans - Conector 5'
                         ]
        self.column_delimitador = ';'
        self.decimal = ','

    
class _gamma():
    def __init__(self) -> None:

        self.colunas  = [
                             r'Tempo'
                            ,r'Deslocamento [mm]'
                            ,r'Força'
                            ,r'Tensão à tração'
                            ,r'Deformação à tração (Deslocamento)'
                            ,r'Deformação digital 1'
                         ]
        self.column_delimitador = ';'
        self.decimal = ','

class _delta():
    def __init__(self) -> None:

        self.colunas  = [
                             r'Tempo'
                            ,r'Deslocamento [mm]'
                            ,r'Força'
                            ,r'Tensão à tração'
                            ,r'Deformação à tração (Deslocamento)'
                         ]
        self.column_delimitador = ';'
        self.decimal = ','


# %%
'''
Reading the .toml file (getting current version)
'''
import toml


print("Obtendo informações do projeto....")
with open('pyproject.toml', 'r') as f:
    config = toml.load(f)

version : str = config['project']['version']
minor_version : str = config['project']['version'].split('.')[-1]
major_version_list : list[str] = config['project']['version'].split('.')[:-1]

# %%
'''
Updating version
'''
print("Atualizando versão...")

new_minor_version = int(minor_version)+1
new_version = ".".join(major_version_list) + f".{new_minor_version}"

# %%
'''
Write the .toml file
'''
print("Escrevendo pyproject.toml...")

with open('pyproject.toml', 'w') as nf:
    nf.write(f"""
[build-system]
requires = ["hatchling"]
build-backend = "hatchling.build"

[project]
name = "experimentalTreatingIsiPol"
version = "{new_version}"
dependencies  = [
        "numpy>=2.1"
        ,"matplotlib>=3.9"
        ,"pandas>=2.2.2"
        ,"scipy>=1.14.0"
        ,"seaborn>=0.13.0"
        ,"plotly>=5.24.1"
        ,"reportlab>=4.2.5"
]
authors = [
  {{ name="Jonas Tieppo da Rocha", email="jonas.rocha@senairs.org.br" }},
]
description = "Um package para auxialar no tratamento de dados"
readme = "README.md"
requires-python = ">=3.9"
classifiers = [
    "Programming Language :: Python :: 3",
    "License :: OSI Approved :: MIT License",
    "Operating System :: OS Independent",
]
[project.urls]
Homepage = "https://github.com/jonastieppo/PostProcessingData"
""")

# %%
'''
deleting dist folder
'''
import shutil
import os

if "dist" in os.listdir(os.getcwd()):
    "Removendo dist"
    shutil.rmtree('dist')

# %%
import os

print("Compilando versão...")
os.system("py -m build")

# %%
